@@ -66,6 +66,7 @@ $surface-dark: {surface_dark};
 fn get_scripts(config: &Config) -> Vec<String> {
 
     let mut scripts = vec![
+        include_str!("../js/index.js").to_string(),
         include_str!("../js/popper.js").to_string(),
         include_str!("../js/form.js").to_string(),
         include_str!("../js/menu.js").to_string(),
@@ -77,6 +78,7 @@ fn get_scripts(config: &Config) -> Vec<String> {
         include_str!("../js/signature-field.js").to_string(),
         include_str!("../js/tabs.js").to_string(),
         include_str!("../js/snackbar.js").to_string(),
+        include_str!("../js/dynamic_content.js").to_string(),
     ];
     if config.features.rich_text_editor {
         scripts.push(include_str!("../js/quill-editor.js").to_string());
